@@ -1,11 +1,10 @@
+use anyhow::{Context, Result};
+use log::{debug, info};
 use std::{
     fs::OpenOptions,
     io::{BufWriter, Write},
 };
 
-use anyhow::{Context, Result};
-use log::{debug, info};
-
 use crate::{
     database::Database,
     util::{now_as_unixepoch_ms, unixepoch_as_ymdhms},
@@ -13,7 +12,7 @@ use crate::{
 
 pub fn export_csv(csv_file: String, db_file: String) -> Result<()> {
     let start = 0;
-    let end = now_as_unixepoch_ms() + 3600_000;
+    let end = now_as_unixepoch_ms() + 3_600_000;
     debug!("start:{}, end:{}", start, end);
 
     let db = Database::open(db_file).context("open 1history db")?;
